@@ -31,7 +31,7 @@ use base qw(CipUX);
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.0');
+    use version; our $VERSION = qv('3.4.0.2');
     use re 'taint';    # Keep tainted any data captured by parens
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -70,13 +70,19 @@ use base qw(CipUX);
             ? $self->l( $arg_r->{pref} )
             : $EMPTY_STRING;
 
+        my $cache_dir
+            = exists $arg_r->{cache_dir}
+            ? $self->l( $arg_r->{cache_dir} )
+            : $EMPTY_STRING;
+
         # +------------------------------------------------------------------+
         # | main
-        my $cfg_hr = $self->cfg( { 'sub' => 'storage', pref => $pref } );
+        my $cfg_hr = $self->cfg(
+            { 'sub' => 'storage', pref => $pref, cache_dir => $cache_dir } );
         $storage_cfg{$ident} = $cfg_hr->{structure};
 
-        my $access_cfg_hr
-            = $self->cfg( { 'sub' => 'access', pref => $pref } );
+        my $access_cfg_hr = $self->cfg(
+            { 'sub' => 'access', pref => $pref, cache_dir => $cache_dir } );
         $access_cfg{$ident} = $access_cfg_hr->{ldap};
 
         # +------------------------------------------------------------------+
@@ -888,15 +894,15 @@ use base qw(CipUX);
         my $cfg_structure_hr = $storage_cfg{ ident $self};
 
         #$cfg_structure_hr = $cfg_structure_hr->{structure};
-        $logger->debug( 'cfg_structure_hr:',
-            { filter => \&Dumper, value => $cfg_structure_hr } );
+        #$logger->debug( 'cfg_structure_hr:',
+        #    { filter => \&Dumper, value => $cfg_structure_hr } );
 
         # test type for all subs:
         my $type_ar = $self->list_storage_type(
             { cfg_structure_hr => $cfg_structure_hr } );
 
-        $logger->info( 'type_ar:',
-            { filter => \&Dumper, value => $type_ar } );
+        #$logger->info( 'type_ar:',
+        #    { filter => \&Dumper, value => $type_ar } );
 
         my %type = ();
         foreach my $t ( @{$type_ar} ) {
@@ -1028,6 +1034,8 @@ use base qw(CipUX);
         my %oid_info = (
             'cipux_account.user'  => 'uidNumber',
             'cipux_account.group' => 'gidNumber',
+            'cipux_share.user'    => 'uidNumber',
+            'cipux_share.group'   => 'gidNumber',
         );
 
         my $supremum = $MIN_OID_NUMBER;
@@ -1100,7 +1108,7 @@ CipUX::Storage - Storage abstraction layer for CipUX
 
 =head1 VERSION
 
-version 3.4.0.0
+version 3.4.0.2
 
 =head1 SYNOPSIS
 
